import type { IPFS } from 'ipfs-core';
import { CID } from 'multiformats/cid';
import { PubSub } from './pubsub';
export interface Link {
    [name: string]: CID | undefined;
}
export declare class Shard<T = any> {
    private ipfs;
    cid: CID;
    private context?;
    private constructor();
    private static encode;
    private static decode;
    static from<T = any>(ipfs: IPFS, cid: CID, context?: {
        namespace: string;
        store: Store;
    }): Promise<Shard<T>>;
    static create<T = any>(ipfs: IPFS, data: T, context?: {
        namespace: string;
        store: Store;
    }): Promise<Shard<T>>;
    get(): Promise<T | null>;
    private refreshStore;
    set(data: T): Promise<void>;
    /**
     * **Links are EXPERIMENTAL**
     */
    links(): Promise<Link>;
    /**
     * **Links are EXPERIMENTAL**
     */
    addLink(name: string, cid: CID): Promise<void>;
    /**
     * **Links are EXPERIMENTAL**
     */
    rmLink(cid: CID): Promise<void>;
}
export declare class Store {
    ipfs: IPFS;
    namespace: string;
    private pubsub;
    private map;
    constructor(ipfs: IPFS, namespace: string, pubsub: PubSub);
    start(): Promise<void>;
    emitUpdate(key: string, value: CID): Promise<void>;
    /**
     * Set data to store
     *
     * @param key key
     * @param data value
     * @returns Shard
     */
    set<T = any>(key: string, data: T): Promise<Shard<T>>;
    /**
     * Get data from Store by key
     *
     * @param key key
     * @param timeout in ms
     * @returns Shard
     */
    get<T = any>(key: string, timeout?: number): Promise<Shard<T> | void>;
}
